You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ace.apache.org by ma...@apache.org on 2012/03/16 16:51:55 UTC

svn commit: r1301604 - in /ace/trunk: ace-integrationtests/src/test/java/org/apache/ace/it/deployment/ ace-integrationtests/src/test/java/org/apache/ace/it/server/ ace-karaf-features/src/main/resources/ ace-log/src/main/java/org/apache/ace/log/ ace-log...

Author: marrs
Date: Fri Mar 16 15:51:55 2012
New Revision: 1301604

URL: http://svn.apache.org/viewvc?rev=1301604&view=rev
Log:
ACE-63 here we go again

Modified:
    ace/trunk/ace-integrationtests/src/test/java/org/apache/ace/it/deployment/DeploymentIntegrationTest.java
    ace/trunk/ace-integrationtests/src/test/java/org/apache/ace/it/server/AssemblyConfigureTest.java
    ace/trunk/ace-integrationtests/src/test/java/org/apache/ace/it/server/MinimalGatewayTest.java
    ace/trunk/ace-karaf-features/src/main/resources/features.xml
    ace/trunk/ace-log/src/main/java/org/apache/ace/log/LogDescriptor.java
    ace/trunk/ace-log/src/main/java/org/apache/ace/log/LogEvent.java
    ace/trunk/ace-log/src/test/java/org/apache/ace/log/LogEventTest.java
    ace/trunk/ace-server-log-store/src/main/java/org/apache/ace/server/log/store/impl/LogStoreImpl.java
    ace/trunk/ace-webui-vaadin/src/main/java/org/apache/ace/webui/vaadin/VaadinClient.java

Modified: ace/trunk/ace-integrationtests/src/test/java/org/apache/ace/it/deployment/DeploymentIntegrationTest.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-integrationtests/src/test/java/org/apache/ace/it/deployment/DeploymentIntegrationTest.java?rev=1301604&r1=1301603&r2=1301604&view=diff
==============================================================================
--- ace/trunk/ace-integrationtests/src/test/java/org/apache/ace/it/deployment/DeploymentIntegrationTest.java (original)
+++ ace/trunk/ace-integrationtests/src/test/java/org/apache/ace/it/deployment/DeploymentIntegrationTest.java Fri Mar 16 15:51:55 2012
@@ -238,11 +238,11 @@ public class DeploymentIntegrationTest e
                 put(EventConstants.EVENT_FILTER, "(successful=true)");
             }
         });
-        configureGateway();
+        configureTarget();
         configureServer();
         assert m_semaphore.tryAcquire(8, TimeUnit.SECONDS) : "Timed out while waiting for deployment to complete.";
         unconfigureServer();
-        unconfigureGateway();
+        unconfigureTarget();
         reg.unregister();
         m_bundleContext.removeBundleListener(this);
     }
@@ -250,11 +250,11 @@ public class DeploymentIntegrationTest e
     private void executeTestWithFailingStream() throws IOException, InterruptedException {
         m_bundleContext.addBundleListener(this);
         registerDeploymentAdminProxy(new FailingDeploymentAdmin(m_deployment, 50));
-        configureGateway();
+        configureTarget();
         configureServer();
         assert m_semaphore.tryAcquire(8, TimeUnit.SECONDS) : "Timed out while waiting for deployment to abort.";
         unconfigureServer();
-        unconfigureGateway();
+        unconfigureTarget();
         unregisterDeploymentAdminProxy();
         m_bundleContext.removeBundleListener(this);
     }
@@ -340,19 +340,19 @@ public class DeploymentIntegrationTest e
         }
     }
 
-    private void configureGateway() throws IOException {
+    private void configureTarget() throws IOException {
         // configure discovery bundle
         setProperty(DiscoveryConstants.DISCOVERY_PID, new Object[][] { { DiscoveryConstants.DISCOVERY_URL_KEY, "http://" + HOST + ":" + TestConstants.PORT } });
         // configure identification bundle
         setProperty(IdentificationConstants.IDENTIFICATION_PID, new Object[][] { { IdentificationConstants.IDENTIFICATION_TARGETID_KEY, GWID } });
         // configure scheduler
         setProperty(SchedulerConstants.SCHEDULER_PID, new Object[][] {
-            { "org.apache.ace.gateway.auditlog.task.AuditLogSyncTask", POLL_INTERVAL },
+            { "org.apache.ace.target.auditlog.task.AuditLogSyncTask", POLL_INTERVAL },
             { "org.apache.ace.deployment.task.DeploymentUpdateTask", POLL_INTERVAL }
             });
     }
 
-    private void unconfigureGateway() throws IOException {
+    private void unconfigureTarget() throws IOException {
         m_config.getConfiguration(DiscoveryConstants.DISCOVERY_PID, null).delete();
         m_config.getConfiguration(IdentificationConstants.IDENTIFICATION_PID, null).delete();
         m_config.getConfiguration(SchedulerConstants.SCHEDULER_PID, null).delete();

Modified: ace/trunk/ace-integrationtests/src/test/java/org/apache/ace/it/server/AssemblyConfigureTest.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-integrationtests/src/test/java/org/apache/ace/it/server/AssemblyConfigureTest.java?rev=1301604&r1=1301603&r2=1301604&view=diff
==============================================================================
--- ace/trunk/ace-integrationtests/src/test/java/org/apache/ace/it/server/AssemblyConfigureTest.java (original)
+++ ace/trunk/ace-integrationtests/src/test/java/org/apache/ace/it/server/AssemblyConfigureTest.java Fri Mar 16 15:51:55 2012
@@ -1,19 +1,20 @@
 /*
- * Copyright 2009 Toni Menzel.
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
- * implied.
- *
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.ace.it.server;
 
@@ -21,8 +22,7 @@ import org.junit.Test;
 import org.ops4j.pax.exam.Option;
 
 /**
- * @author Toni Menzel
- * @since Dec 16, 2009
+ * 
  */
 public class AssemblyConfigureTest
 {
@@ -32,6 +32,6 @@ public class AssemblyConfigureTest
     {
         System.setProperty( "java.protocol.handler.pkgs", "org.ops4j.pax.url" );
         // TODO avoid to use hard coded version
-        Option[] options = AssemblyConfigure.get( "ace-gateway","mvn:org.apache.ace/org.apache.ace.target.devgateway/0.8.1-SNAPSHOT/zip/distribution" );
+        Option[] options = AssemblyConfigure.get( "ace-target","mvn:org.apache.ace/org.apache.ace.target.devgateway/0.8.1-SNAPSHOT/zip/distribution" );
     }
 }

Modified: ace/trunk/ace-integrationtests/src/test/java/org/apache/ace/it/server/MinimalGatewayTest.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-integrationtests/src/test/java/org/apache/ace/it/server/MinimalGatewayTest.java?rev=1301604&r1=1301603&r2=1301604&view=diff
==============================================================================
--- ace/trunk/ace-integrationtests/src/test/java/org/apache/ace/it/server/MinimalGatewayTest.java (original)
+++ ace/trunk/ace-integrationtests/src/test/java/org/apache/ace/it/server/MinimalGatewayTest.java Fri Mar 16 15:51:55 2012
@@ -1,18 +1,20 @@
 /*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
  *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
- * implied.
- *
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
 package org.apache.ace.it.server;
 
@@ -34,8 +36,7 @@ import org.osgi.framework.Bundle;
 import org.osgi.framework.BundleContext;
 
 /**
- * @author Toni Menzel
- * @since Dec 10, 2009
+ * 
  */
 @RunWith( JUnit4TestRunner.class )
 public class MinimalGatewayTest

Modified: ace/trunk/ace-karaf-features/src/main/resources/features.xml
URL: http://svn.apache.org/viewvc/ace/trunk/ace-karaf-features/src/main/resources/features.xml?rev=1301604&r1=1301603&r2=1301604&view=diff
==============================================================================
--- ace/trunk/ace-karaf-features/src/main/resources/features.xml (original)
+++ ace/trunk/ace-karaf-features/src/main/resources/features.xml Fri Mar 16 15:51:55 2012
@@ -139,7 +139,7 @@
         <bundle>mvn:org.apache.ace/org.apache.ace.managementagent/${project.version}</bundle>
     </feature>
 
-    <feature name="ace-gateway" version="${project.version}" resolver="(obr)">
+    <feature name="ace-target" version="${project.version}" resolver="(obr)">
         <bundle>mvn:org.apache.ace/org.apache.ace.gateway.log/${project.version}</bundle>
         <bundle>mvn:org.apache.ace/org.apache.ace.gateway.log.store/${project.version}</bundle>
     </feature>

Modified: ace/trunk/ace-log/src/main/java/org/apache/ace/log/LogDescriptor.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-log/src/main/java/org/apache/ace/log/LogDescriptor.java?rev=1301604&r1=1301603&r2=1301604&view=diff
==============================================================================
--- ace/trunk/ace-log/src/test/java/org/apache/ace/log/LogEventTest.java (original)
+++ ace/trunk/ace-log/src/test/java/org/apache/ace/log/LogEventTest.java Fri Mar 16 15:51:55 2012
@@ -42,7 +42,7 @@ public class LogEventTest {
     @Test(groups = { UNIT })
     public void deserializeLogEvent() {
         LogEvent e = new LogEvent("gwid$kgwid$n$r$$,1,2,3," + AuditEvent.FRAMEWORK_STARTED + ",a,1,b,2,c,3");
-        assert e.getGatewayID().equals("gwid,gwid\n\r$") : "Gateway ID is not correctly parsed";
+        assert e.getTargetID().equals("gwid,gwid\n\r$") : "Gateway ID is not correctly parsed";
         assert e.getLogID() == 1 : "Log ID is not correctly parsed";
         assert e.getID() == 2 : "ID is not correctly parsed";
         assert e.getTime() == 3 : "Time is not correctly parsed";

Modified: ace/trunk/ace-server-log-store/src/main/java/org/apache/ace/server/log/store/impl/LogStoreImpl.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-server-log-store/src/main/java/org/apache/ace/server/log/store/impl/LogStoreImpl.java?rev=1301604&r1=1301603&r2=1301604&view=diff
==============================================================================
--- ace/trunk/ace-server-log-store/src/main/java/org/apache/ace/server/log/store/impl/LogStoreImpl.java (original)
+++ ace/trunk/ace-server-log-store/src/main/java/org/apache/ace/server/log/store/impl/LogStoreImpl.java Fri Mar 16 15:51:55 2012
@@ -293,11 +293,11 @@ public class LogStoreImpl implements Log
         Map<String, Map<Long, List<LogEvent>>> result = new HashMap<String, Map<Long, List<LogEvent>>>();
         for (LogEvent event : events) {
             Map<Long, List<LogEvent>> gateway = result
-                    .get(event.getGatewayID());
+                    .get(event.getTargetID());
 
             if (gateway == null) {
                 gateway = new HashMap<Long, List<LogEvent>>();
-                result.put(event.getGatewayID(), gateway);
+                result.put(event.getTargetID(), gateway);
             }
 
             List<LogEvent> list = gateway.get(event.getLogID());

Modified: ace/trunk/ace-webui-vaadin/src/main/java/org/apache/ace/webui/vaadin/VaadinClient.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-webui-vaadin/src/main/java/org/apache/ace/webui/vaadin/VaadinClient.java?rev=1301604&r1=1301603&r2=1301604&view=diff
==============================================================================
--- ace/trunk/ace-webui-vaadin/src/main/java/org/apache/ace/webui/vaadin/VaadinClient.java (original)
+++ ace/trunk/ace-webui-vaadin/src/main/java/org/apache/ace/webui/vaadin/VaadinClient.java Fri Mar 16 15:51:55 2012
@@ -113,7 +113,7 @@ public class VaadinClient extends com.va
 
     private static final long serialVersionUID = 1L;
     private static long SESSION_ID = 12345;
-    private static String gatewayRepo = "gateway";
+    private static String targetRepo = "target";
     private static String shopRepo = "shop";
     private static String deployRepo = "deployment";
     private static String customerName = "apache";
@@ -132,7 +132,7 @@ public class VaadinClient extends com.va
     private volatile StatefulTargetRepository m_statefulTargetRepository;
     private volatile Artifact2FeatureAssociationRepository m_artifact2GroupAssociationRepository;
     private volatile Feature2DistributionAssociationRepository m_group2LicenseAssociationRepository;
-    private volatile Distribution2TargetAssociationRepository m_license2GatewayAssociationRepository;
+    private volatile Distribution2TargetAssociationRepository m_license2TargetAssociationRepository;
     private volatile RepositoryAdmin m_admin;
     private volatile LogService m_log;
     private String m_sessionID;
@@ -243,7 +243,7 @@ public class VaadinClient extends com.va
     private void initGrid(User user) {
         Authorization auth = m_userAdmin.getAuthorization(user);
         int count = 0;
-        for (String role : new String[] { "viewBundle", "viewGroup", "viewLicense", "viewGateway" }) {
+        for (String role : new String[] { "viewBundle", "viewGroup", "viewLicense", "viewTarget" }) {
             if (auth.hasRole(role)) {
                 count++;
             }
@@ -297,7 +297,7 @@ public class VaadinClient extends com.va
         m_targetsPanel = createTargetsPanel(m_mainWindow);
         m_targetToolbar = createAddTargetButton(m_mainWindow);
 
-        if (auth.hasRole("viewGateway")) {
+        if (auth.hasRole("viewTarget")) {
             m_grid.addComponent(m_targetsPanel, count, 2);
             m_grid.addComponent(m_targetToolbar, count, 1);
         }
@@ -386,7 +386,7 @@ public class VaadinClient extends com.va
                     target.register();
                     target.setAutoApprove(true);
                 }
-                m_license2GatewayAssociationRepository.create(getDistribution(left), target.getTargetObject());
+                m_license2TargetAssociationRepository.create(getDistribution(left), target.getTargetObject());
             }
         });
         m_targetsPanel.setDropHandler(new AssociationDropHandler(m_distributionsPanel, (Table) null) {
@@ -397,7 +397,7 @@ public class VaadinClient extends com.va
                     target.register();
                     target.setAutoApprove(true);
                 }
-                m_license2GatewayAssociationRepository.create(getDistribution(left), target.getTargetObject());
+                m_license2TargetAssociationRepository.create(getDistribution(left), target.getTargetObject());
             }
 
             @Override
@@ -426,7 +426,7 @@ public class VaadinClient extends com.va
             // @formatter:off
             context.addShopRepository(new URL(m_aceHost, endpoint), customerName, shopRepo, true)
                 .setObrBase(m_obrUrl)
-                .addTargetRepository(new URL(m_aceHost, endpoint), customerName, gatewayRepo, true)
+                .addTargetRepository(new URL(m_aceHost, endpoint), customerName, targetRepo, true)
                 .addDeploymentRepository(new URL(m_aceHost, endpoint), customerName, deployRepo, true);
             // @formatter:on
             m_admin.login(context);
@@ -734,7 +734,7 @@ public class VaadinClient extends com.va
                             List<Distribution2TargetAssociation> associations = object
                                 .getAssociationsWith((TargetObject) other);
                             for (Distribution2TargetAssociation association : associations) {
-                                m_license2GatewayAssociationRepository.remove(association);
+                                m_license2TargetAssociationRepository.remove(association);
                             }
                             m_associations.removeAssociatedItem(object);
                             m_table.requestRepaint();
@@ -802,7 +802,7 @@ public class VaadinClient extends com.va
                             List<Distribution2TargetAssociation> associations = object
                                 .getAssociationsWith((DistributionObject) other);
                             for (Distribution2TargetAssociation association : associations) {
-                                m_license2GatewayAssociationRepository.remove(association);
+                                m_license2TargetAssociationRepository.remove(association);
                             }
                             m_associations.removeAssociatedItem(object);
                             m_table.requestRepaint();
@@ -814,12 +814,6 @@ public class VaadinClient extends com.va
                     };
                     HorizontalLayout buttons = new HorizontalLayout();
                     buttons.addComponent(removeLinkButton);
-                    // next line commented out because removing stateful targets
-                    // currently is not possible
-                    // buttons.addComponent(new
-                    // RemoveItemButton<StatefulGatewayObject,
-                    // StatefulGatewayRepository>(statefulTarget,
-                    // m_statefulTargetRepository));
                     item.getItemProperty(ACTIONS).setValue(buttons);
                 }
             }
@@ -1001,7 +995,7 @@ public class VaadinClient extends com.va
     }
 
     /**
-     * Create a new Target (StatefulGatewayObject) in the statefulTargetRepository
+     * Create a new Target (StatefulTargetObject) in the statefulTargetRepository
      * 
      * @param name Name of the new Target
      * @param description Description of the new Target
--- ace/trunk/ace-log/src/main/java/org/apache/ace/log/LogDescriptor.java (original)
+++ ace/trunk/ace-log/src/main/java/org/apache/ace/log/LogDescriptor.java Fri Mar 16 15:51:55 2012
@@ -27,32 +27,32 @@ import org.apache.ace.util.Codec;
 /**
  * Instances of this class represent a range of log events. Such a range is defined by:
  * <ul>
  * <li>A unique gateway ID</li>
  * <li>A log ID unique for this gateway</li>
  * <li>A set of event IDs</li>
  * </ul>
  */
 public class LogDescriptor {
     private final SortedRangeSet m_rangeSet;
     private final long m_logID;
-    private final String m_gatewayID;
+    private final String m_targetID;
 
     /**
      * Create a log event range.
      *
      * @param gatewayID The unique gateway ID
      * @param logID The unique log ID for this gateway
      * @param rangeSet The set of event IDs
      */
-    public LogDescriptor(String gatewayID, long logID, SortedRangeSet rangeSet) {
-        m_gatewayID = gatewayID;
+    public LogDescriptor(String targetID, long logID, SortedRangeSet rangeSet) {
+        m_targetID = targetID;
         m_logID = logID;
         m_rangeSet = rangeSet;
     }
 
     /**
      * Create a log event range from a string representation. String representations
      * should be formatted as "gatewayID,logID,eventIDs" where each substring is formatted
      * using <code>Codec.encode(string)</code> method.
      *
      * Throws an <code>IllegalArgumentException</code> when the string representation is not correctly formatted.
@@ -62,7 +62,7 @@ public class LogDescriptor {
     public LogDescriptor(String representation) {
         try {
             StringTokenizer st = new StringTokenizer(representation, ",");
-            m_gatewayID = Codec.decode(st.nextToken());
+            m_targetID = Codec.decode(st.nextToken());
             m_logID = Long.parseLong(st.nextToken());
             String rangeSet = "";
             if (st.hasMoreTokens()) {
@@ -76,18 +76,18 @@ public class LogDescriptor {
     }
 
     /**
      * Get the unique gateway identifier.
      *
      * @return Unique gateway identifier.
      */
     public String getTargetID() {
-        return m_gatewayID;
+        return m_targetID;
     }
 
     /**
      * Get the unique log identifier for this gateway.
      *
      * @return Unique log identifier for this gateway.
      */
     public long getLogID() {
         return m_logID;
@@ -110,7 +110,7 @@ public class LogDescriptor {
      */
     public String toRepresentation() {
         StringBuffer result = new StringBuffer();
-        result.append(Codec.encode(m_gatewayID));
+        result.append(Codec.encode(m_targetID));
         result.append(',');
         result.append(m_logID);
         result.append(',');
@@ -27,32 +27,32 @@ import org.apache.ace.util.Codec;
  * Instances of this class represent a range of log events. Such a range is defined by:
  * <ul>
- * <li>A unique gateway ID</li>
- * <li>A log ID unique for this gateway</li>
+ * <li>A unique target ID</li>
+ * <li>A log ID unique for this target</li>
  * <li>A set of event IDs</li>
  * </ul>
@@ -27,32 +27,32 @@ import org.apache.ace.util.Codec;
      * Create a log event range.
      *
-     * @param gatewayID The unique gateway ID
-     * @param logID The unique log ID for this gateway
+     * @param targetID The unique target ID
+     * @param logID The unique log ID for this target
      * @param rangeSet The set of event IDs
      */
@@ -27,32 +27,32 @@ import org.apache.ace.util.Codec;
     /**
      * Create a log event range from a string representation. String representations
-     * should be formatted as "gatewayID,logID,eventIDs" where each substring is formatted
+     * should be formatted as "targetID,logID,eventIDs" where each substring is formatted
      * using <code>Codec.encode(string)</code> method.
      *
@@ -76,18 +76,18 @@ public class LogDescriptor {
 
     /**
-     * Get the unique gateway identifier.
+     * Get the unique target identifier.
      *
@@ -76,18 +76,18 @@ public class LogDescriptor {
      *
-     * @return Unique gateway identifier.
+     * @return Unique target identifier.
      */
     public String getTargetID() {
@@ -76,18 +76,18 @@ public class LogDescriptor {
 
     /**
-     * Get the unique log identifier for this gateway.
+     * Get the unique log identifier for this target.
      *
@@ -76,18 +76,18 @@ public class LogDescriptor {
      *
-     * @return Unique log identifier for this gateway.
+     * @return Unique log identifier for this target.
      */
     public long getLogID() {

Modified: ace/trunk/ace-log/src/main/java/org/apache/ace/log/LogEvent.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-log/src/main/java/org/apache/ace/log/LogEvent.java?rev=1301604&r1=1301603&r2=1301604&view=diff
==============================================================================
--- ace/trunk/ace-log/src/main/java/org/apache/ace/log/LogEvent.java (original)
+++ ace/trunk/ace-log/src/main/java/org/apache/ace/log/LogEvent.java Fri Mar 16 15:51:55 2012
@@ -25,18 +25,18 @@ import java.util.StringTokenizer;
 import org.apache.ace.util.Codec;
 
 /**
  * Log event from a specific gateway and log.
  */
 public class LogEvent implements Comparable {
-    private final String m_gatewayID;
+    private final String m_targetID;
     private final long m_logID;
     private final long m_id;
     private final long m_time;
     private final int m_type;
     private final Dictionary m_properties;
 
-    public LogEvent(String gatewayID, long logID, long id, long time, int type, Dictionary properties) {
-        m_gatewayID = gatewayID;
+    public LogEvent(String targetID, long logID, long id, long time, int type, Dictionary properties) {
+        m_targetID = targetID;
         m_logID = logID;
         m_id = id;
         m_time = time;
@@ -44,14 +44,14 @@ public class LogEvent implements Compara
         m_properties = properties;
     }
 
-    public LogEvent(String gatewayID, LogEvent source) {
-        this(gatewayID, source.getLogID(), source.getID(), source.getTime(), source.getType(), source.getProperties());
+    public LogEvent(String targetID, LogEvent source) {
+        this(targetID, source.getLogID(), source.getID(), source.getTime(), source.getType(), source.getProperties());
     }
 
     public LogEvent(String representation) {
         try {
             StringTokenizer st = new StringTokenizer(representation, ",");
-            m_gatewayID = Codec.decode(st.nextToken());
+            m_targetID = Codec.decode(st.nextToken());
             m_logID = Long.parseLong(st.nextToken());
             m_id = Long.parseLong(st.nextToken());
             m_time = Long.parseLong(st.nextToken());
@@ -69,7 +69,7 @@ public class LogEvent implements Compara
 
     public String toRepresentation() {
         StringBuffer result = new StringBuffer();
-        result.append(Codec.encode(m_gatewayID));
+        result.append(Codec.encode(m_targetID));
         result.append(',');
         result.append(m_logID);
         result.append(',');
@@ -90,14 +90,14 @@ public class LogEvent implements Compara
     }
 
     /**
      * Returns the unique ID of the gateway that created this event.
      */
-    public String getGatewayID() {
-        return m_gatewayID;
+    public String getTargetID() {
+        return m_targetID;
     }
 
     /**
      * Returns the unique log ID of the log. This ID is unique within a gateway.
      */
     public long getLogID() {
         return m_logID;
@@ -137,7 +137,7 @@ public class LogEvent implements Compara
         }
         if (o instanceof LogEvent) {
             LogEvent event = (LogEvent) o;
-            return m_gatewayID.equals(event.m_gatewayID)
+            return m_targetID.equals(event.m_targetID)
                 && m_logID == event.m_logID && m_id == event.m_id;
         }
 
@@ -145,12 +145,12 @@ public class LogEvent implements Compara
     }
 
     public int hashCode() {
-        return (int) (m_gatewayID.hashCode() + m_logID + m_id);
+        return (int) (m_targetID.hashCode() + m_logID + m_id);
     }
 
     public int compareTo(Object o) {
         LogEvent e = (LogEvent) o;
-        final int cmp = m_gatewayID.compareTo(e.m_gatewayID);
+        final int cmp = m_targetID.compareTo(e.m_targetID);
         if (cmp != 0) {
             return cmp;
         }
@@ -25,18 +25,18 @@ import java.util.StringTokenizer;
 
 /**
- * Log event from a specific gateway and log.
+ * Log event from a specific target and log.
  */
 public class LogEvent implements Comparable {
@@ -90,14 +90,14 @@ public class LogEvent implements Compara
 
     /**
-     * Returns the unique ID of the gateway that created this event.
+     * Returns the unique ID of the target that created this event.
      */
@@ -90,14 +90,14 @@ public class LogEvent implements Compara
 
     /**
-     * Returns the unique log ID of the log. This ID is unique within a gateway.
+     * Returns the unique log ID of the log. This ID is unique within a target.
      */
     public long getLogID() {

Modified: ace/trunk/ace-log/src/test/java/org/apache/ace/log/LogEventTest.java
URL: http://svn.apache.org/viewvc/ace/trunk/ace-log/src/test/java/org/apache/ace/log/LogEventTest.java?rev=1301604&r1=1301603&r2=1301604&view=diff
==============================================================================